<?php
/*
Plugin Name: COD IVR
Plugin URI: https://codivr.com/
Description: COD Order verified by call.
Version: 2.0.2
Author: Onjection
Author URI: https://codivr.com/
License: GPL
@author Onjection
@package WooCommerce COD IVR
@version 2.0.2
*/

/*  Copyright 2015  Onjection Solutions  (email : contact@Onjection.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
if ( ! class_exists( 'WC_cod_ivr_plugin' ) ) :
class WC_cod_ivr_plugin {

    public function __construct() {
        add_action( 'plugins_loaded', array( $this, 'init' ) );
    }
    /**
     * Initialize the plugin.
    */
    public function init() {
        // Checks if WooCommerce is installed.
        if ( class_exists( 'WC_Integration' ) ) {
            
            add_filter( 'woocommerce_settings_tabs_array', __CLASS__ . '::add_settings_tab', 50 );
            add_action( 'woocommerce_settings_tabs_cod_ivr', __CLASS__ . '::settings_tab' );
            add_action( 'woocommerce_update_options_cod_ivr', __CLASS__ . '::update_settings' );

            // Set the plugin slug
            define( 'MY_PLUGIN_SLUG', 'wc-settings' );
            // Setting action for plugin
            add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'WC_cod_ivr_plugin_action_links' );
        }
    }

    public static function add_settings_tab( $settings_tabs ) {
        $settings_tabs['cod_ivr'] = __( 'COD IVR', 'woocommerce-cod-ivr' );
        return $settings_tabs;
    }

    public static function settings_tab() {
        woocommerce_admin_fields( self::get_settings() );
    }

    public static function update_settings() {
        woocommerce_update_options( self::get_settings() );
    }

    public static function get_settings() {
        $register_url = "<a target='_blank' href='https://codivr.com/register.php'>click here</a>";
        $settings = array(
            'section_title' => array(
                'name'     => __( 'COD IVR Setting', 'woocommerce-cod-ivr' ),
                'type'     => 'title',
                'desc'     => '',
                'id'       => 'wc_cod_ivr_section_title'
            ),
            'username' => array(
                'name' => __( 'User Name', 'woocommerce-cod-ivr' ),
                'type' => 'text',
                'desc' => __( '', 'woocommerce-cod-ivr' ),
                'id'   => 'wc_cod_ivr_username'
            ),
            'license_key' => array(
                'name' => __( 'License Key', 'woocommerce-cod-ivr' ),
                'type' => 'text',
                'desc' => __( '', 'woocommerce-cod-ivr' ),
                'id'   => 'wc_cod_ivr_license_key'
            ),
            'description' => array(
                'name' => __( '', 'woocommerce-cod-ivr' ),
                'type' => 'title',
                'desc' => __( "If don't have user name & license key please register here $register_url" ),
                'id'   => 'wc_cod_ivr_description'
            ),
            'section_end' => array(
                 'type' => 'sectionend',
                 'id' => 'wc_cod_ivr_section_end'
            )
        );

        return apply_filters( 'wc_cod_ivr_settings', $settings );
    }
}

$WC_cod_ivr_plugin = new WC_cod_ivr_plugin();

function COD_IVR_remove_http($url) {
    $disallowed = array('http://', 'https://');
    foreach($disallowed as $d) {
       if(strpos($url, $d) === 0) {
          return str_replace($d, '', $url);
       }
    }
    return $url;
}

define('COD_IVR_STORE_URL',COD_IVR_remove_http(site_url()));
define('COD_MAIN_CALL_API_URL','https://codivr.com/embedded/cod_confirmation/cod_app_api/call_api.php');
define('COD_GET_CALL_API_URL','https://codivr.com/embedded/cod_confirmation/cod_app_api/get_api.php');

//add setting link
function WC_cod_ivr_plugin_action_links( $links ) {
    $links[] = '<a href="'. menu_page_url( MY_PLUGIN_SLUG, false ) .'&tab=cod_ivr">Settings</a>';
    return $links;
}

/**
 * Adds 'Call Response' column header to 'Orders' page immediately after 'Order Status' column.
 *
 * @param string[] $columns
 * @return string[] $new_columns
 */
function sv_wc_cogs_add_call_response_column_header( $columns ) {
   
    $new_columns = array();
    foreach ( $columns as $column_name => $column_info ) {

        $new_columns[ $column_name ] = $column_info;

        if ( 'order_status' === $column_name ) {
            $new_columns['call_response'] = __( 'COD IVR Call Response', 'my-textdomain' );
        }
    }

    return $new_columns;
}
add_filter( 'manage_edit-shop_order_columns', 'sv_wc_cogs_add_call_response_column_header', 20 );

/**
 * Adds 'Call Response' column content to 'Orders' page immediately after 'Order Status' column.
 *
 * @param string[] $column name of column being displayed
 */
function sv_wc_cogs_add_call_response_column_content( $column ) {
    global $post;
    global $wpdb;
    
    $callTag = '';
    if ( 'call_response' === $column ) {

        $callTag = fetch_order_call_tag($post->ID);
        if(empty($callTag)){
            echo "--";
        }else{
            echo $callTag;
        }
    }
}
add_action( 'manage_shop_order_posts_custom_column', 'sv_wc_cogs_add_call_response_column_content' );

/**
 * Adjusts the styles for the new 'Call Response' column.
 */
function sv_wc_cogs_add_call_response_column_style() {

    $css = '.widefat .column-order_date, .widefat .column-call_response { width: 9%; }';
    wp_add_inline_style( 'woocommerce_admin_styles', $css );
}
add_action( 'admin_print_styles', 'sv_wc_cogs_add_call_response_column_style' );

/* Get Curl response */
function COD_call_api_order($params,$url){   

    $license_key = get_option( 'wc_cod_ivr_license_key' );
    $data_string = json_encode($params);
    $curl        = curl_init();
    curl_setopt($curl, CURLOPT_HTTPHEADER, array(
        "Licensekey: $license_key",
        "Content-Type: application/json"
    ));
    curl_setopt($curl, CURLOPT_URL, $url);
    curl_setopt($curl, CURLOPT_POST, true);
    curl_setopt($curl, CURLOPT_POSTFIELDS, $data_string);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($curl, CURLOPT_FOLLOWLOCATION, 1);
    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
   
    $output = curl_exec($curl);
    curl_close($curl);
    return $output;     

}

/* Trigger order hook */
function new_order_callback($order_id)
{
    global $wpdb;
    $gatway = get_post_meta($order_id, '_payment_method', true );
    $params = array();
    if($gatway == 'cod'){
        $dp         = wc_get_price_decimals();
        $params['order_id'] = $order_id;
        $params['user_name'] = get_option( 'wc_cod_ivr_username' );
        $params['store_url'] = COD_IVR_STORE_URL;
        $order = wc_get_order( $order_id );
        $order_data = $order->get_data(); 
        $items = $order->get_items();
        $product_info = array();
        foreach ( $items as $item ) {
            $new_item = array();
            $product_name = $item->get_name();
            $product_id = $item->get_product_id();
            $quantity     = $item->get_quantity(); 

            $product        = $item->get_product(); // Get the WC_Product object
            $product_sku    = $product->get_sku();
            $product_price  = $product->get_price();

            $new_item['id'] = $product_id;
            $new_item['title'] = $product_name;
            $new_item['quantity'] = $quantity;
            $new_item['price'] = $product_price;
            $new_item['sku'] = $product_sku;

            $product_info[] = $new_item;
        }
    
        $params['customer_contact'] = $order_data['billing']['phone'];
        $params['country_code'] = $order_data['billing']['country'];
        $params['order_amount'] = wc_format_decimal( $order->get_total(), $dp );
        $params['currency'] = get_woocommerce_currency_symbol();
        $params['product_info'] = $product_info;

        $url = COD_MAIN_CALL_API_URL;
       
        $result = COD_call_api_order($params, $url);
    }
}
add_action('woocommerce_thankyou','new_order_callback',10,1 ); 

/* get order wise call status */
function fetch_order_call_tag($order_id) {

    global $wpdb;
    $params = array();
   
    $params['user_name'] = get_option( 'wc_cod_ivr_username' );
    $params['store_url'] = COD_IVR_STORE_URL;
    $params['orderid'] = $order_id;
    $params['license_key'] = get_option( 'wc_cod_ivr_license_key' );

    $url = COD_GET_CALL_API_URL;
    $result = COD_call_api_order($params, $url);
    $result = json_decode($result);
    $callTag = '';
    if(!empty($result)){
        foreach($result as $re){
        }
        if(!empty($re)){
            if(isset($re->call_type) && $re->call_type == 6){
                $callTag = (isset($re->order_tag) ? $re->order_tag : '').(isset($re->call_type_desc) ? '-'.$re->call_type_desc : '');
            }else{
                $callTag = (isset($re->order_tag) ? $re->order_tag : '');
            }
        }
    }    
    return $callTag;
    
}

endif;